package WWW::Search::Google;
use strict;
use warnings;
our $VERSION = '0.23';

=head1 NAME

WWW::Search::Google - Search Google via SOAP

=head1 SYNOPSIS

  # no longer working

=head1 DESCRIPTION

Google removed their Search SOAP API in December 2006, so this
module will not do anything. I recomend you use L<Yahoo::Search>
instead.

=head1 AUTHOR

Leon Brocard E<lt>F<acme@astray.com>E<gt>

=head1 COPYRIGHT

Copyright (C) 2002, Leon Brocard

This module is free software; you can redistribute it or modify it
under the same terms as Perl itself.

=cut

1;
